==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/gods/dialogs_nl.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Ik heb het idee dat we zodadelijk iets vreselijks gaan ontdekken.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Ik heb het altijd al geweten: de goden zijn gek.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("God is getikt en de wereld is zijn speelgoed.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Ik denk dat je gelijk hebt.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Ik vrees dat je gelijk hebt.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Ja, schokkend.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("We kunnen we eraan doen?")


dialogId("lod-v-internovat", "font_big", "We can`t leave it this way. We must incarcerate them.")
dialogStr("Zo kunnen we de boel niet achterlaten. We moeten ze onschadelijk maken.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Hoe zullen we dat dan aanpakken?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Stop ze in het gek... ik bedoel in het speciale verblijf van de VDTO.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Goed idee. Zullen we ze allebij dan maar meenemen?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Natuurlijk. Als we er hier ook maar eentje achterlaten kan hij allemaal rare dingen gaan doen. Hij zou golf kunnen gaan spelen, bij voorbeeld.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Niet met deze club. Ik denk dat we blij moeten zijn als we er eentje kunnen afvoeren. De andere wordt dan vast veel minder gevaarlijk.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Zo. Welke dan?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("De gele.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("De blauwe.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Die gele.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Die blauwe.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Dat laten we aan speler over.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Dat kunnen we beter aan de speler over laten.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Moet je naar die club kijken: daar is iets vreselijks mee gebeurd.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Waarschijnlijk heeft er een roze monster aan gezogen.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Moeder had gelijk. Abnormaal spelgedrag is de bron van het Kwaad.")


dialogId("lod-m-palka", "font_small", "That`s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("Dat is waar. Het zou veel makkelijker zijn als dat tafeltennis betje ergens anders was.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Is het je trouwens opgevallen dat de echte golfbal linksboven ligt en dat dat ding rechtsonder een cricketbal is?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Is dat verborgen symboliek?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Weet ik veel.")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Ik dacht dat dat daarboven een tennisbal was.")


dialogId("lod-v-rozliseni", "font_big", "It`s hard to say with this screen resolution.")
dialogStr("Het is moeilijk te zien bij deze schermresolutie.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Deze keer is het ons doel om een van die goden hier weg te krijgen.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Plons!")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Plons!")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Plons!")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Plons!")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Plons!")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("Raak!")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("Raak!")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("Raak!")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("Raak!")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Gezonken!")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Gezonken!")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Gezonken")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("Ik heb gewonnen, sukkel.")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Ik begin!")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Goed!")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Zullen we nog een keertje spelen?")


dialogId("b1-nepodvadim", "font_yellow", "I don`t cheat.")
dialogStr("Ik speel niet vals!")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("Het was vast een foutje...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Plons!")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Plons!")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Plons!")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Plons!")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Plons!")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Raak!")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Raak!")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Raak!")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Raak!")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Gezonken!")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Gezonken!")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Gezonken!")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Ha, ha, ha... ik heb gewonnen!")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Zo!")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("Zullen we het nog een keertje proberen?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("Je hebt dit al een keertje geprobeerd!")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("Dat heb je al een keer gezegd!")


dialogId("b2-nemuze", "font_cyan", "It can`t be a miss on this space.")
dialogStr("Op dat vakje kan het niet mis zijn!")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Je speelt vals!!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss`!")
dialogStr("Dat vakje heb ik al geprobeerd - en jij zei `Plons'!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/gods/dialogs_nl.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Ik heb het idee dat we zodadelijk iets vreselijks gaan ontdekken.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Ik heb het altijd al geweten: de goden zijn gek.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("God is gek en de wereld is zijn speelgoed.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Ik denk dat je gelijk hebt.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Ik vrees dat je gelijk hebt.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Ja, schokkend.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("Wat kunnen we eraan doen?")


dialogId("lod-v-internovat", "font_big", "We can’t leave it this way. We must incarcerate them.")
dialogStr("Zo kunnen we de boel niet achterlaten. We moeten ze onschadelijk maken.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Hoe zullen we dat dan aanpakken?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("We stoppen ze in het gest... ik bedoel in het speciale verblijf van de VDTO.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Goed idee. Zullen we ze allebei dan maar meenemen?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Natuurlijk. Als we er hier ook maar eentje achterlaten kan hij allemaal rare dingen gaan doen. Hij zou golf kunnen gaan spelen, bij voorbeeld.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Niet met deze club. Ik denk dat we blij moeten zijn als we er eentje kunnen afvoeren. De andere wordt dan vast veel minder gevaarlijk.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Zo. Welke dan?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("De gele.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("De blauwe.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Die gele.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Die blauwe.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Dat laten we aan speler over.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Dat kunnen we beter aan de speler over laten.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Moet je naar die club kijken: daar is iets vreselijks mee gebeurd.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Waarschijnlijk heeft er een roze monster aan gezogen.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Mijn moeder had gelijk. Abnormaal speelgedrag is de bron van het Kwaad.")


dialogId("lod-m-palka", "font_small", "That’s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("Dat is waar. Het zou veel makkelijker zijn als dat tafeltennisbatje ergens anders was.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Is het je trouwens opgevallen dat de echte golfbal linksboven ligt en dat dat ding rechtsonder een cricketbal is?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Is dat verborgen symboliek?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Weet ik veel.")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Ik dacht dat dat daarboven een tennisbal was.")


dialogId("lod-v-rozliseni", "font_big", "It’s hard to say with this screen resolution.")
dialogStr("Het is moeilijk te zien bij deze schermresolutie.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Deze keer is het ons doel om een van die goden hier weg te krijgen.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Plons!")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Plons!")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Plons!")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Plons!")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Plons!")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("Raak!")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("Raak!")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("Raak!")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("Raak!")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Gezonken!")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Gezonken!")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Gezonken")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("Ik heb gewonnen, sukkel.")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Ik begin!")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Goed!")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Zullen we nog een keertje spelen?")


dialogId("b1-nepodvadim", "font_yellow", "I don’t cheat.")
dialogStr("Ik speel niet vals!")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("Het was vast een foutje...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Plons!")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Plons!")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Plons!")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Plons!")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Plons!")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Raak!")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Raak!")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Raak!")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Raak!")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Gezonken!")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Gezonken!")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Gezonken!")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Ha, ha, ha... ik heb gewonnen!")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Zo!")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("Zullen we het nog een keertje proberen?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("Je hebt dit al een keertje geprobeerd!")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("Dat heb je al een keer gezegd!")


dialogId("b2-nemuze", "font_cyan", "It can’t be a miss on this space.")
dialogStr("Op dat vakje kan het niet mis zijn!")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Je speelt vals!!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss’!")
dialogStr("Dat vakje heb ik al geprobeerd - en jij zei \"Plons\"!")
